/*
 * GQoob
 * (C) 2002 John Ellis
 *
 * Author: John Ellis
 *
 * This software is released under the GNU General Public License (GNU GPL).
 * Please read the included file COPYING for more information.
 * This software comes with no warranty of any kind, use at your own risk!
 */


#include "gqoob.h"
#include "utils_xine.h"

#include "display.h"
#include "display_xine.h"
#include "io_xine.h"
#include "players.h"
#include "ui2_main.h"
#include "ui2_parse.h"
#include "ui2_util.h"
#include "ui_fileops.h"


#define FULLSCREEN_EDGE 4


/*
 *-----------------------------------------------------------------------------
 * btn calls
 *-----------------------------------------------------------------------------
 */

void btn_speed_up_pressed(void)
{
	gqoob_xine_speed_step(TRUE);
	display_set_status(FALSE, FALSE);
}

void btn_speed_down_pressed(void)
{
	gqoob_xine_speed_step(FALSE);
	display_set_status(FALSE, FALSE);
}

void skip_by_time(gint increment)
{
	gint new_time;

	if (increment == 0) return;
	if (status != STATUS_PAUSE && status != STATUS_PLAY) return;

	new_time = seconds + increment;
	if (new_time >= seconds + seconds_remaining - 1) return;
	if (new_time < 0) new_time = 0;

	playback_exec_command(EXEC_SEEK, current_song_get_data(), new_time);
}

/*
 *-----------------------------------------------------------------------------
 * full screen
 *-----------------------------------------------------------------------------
 */

static gint fullscreen_enabled = FALSE;
static gint fullscreen_key_focus = TRUE;
static UIData *fullscreen_ui = NULL;

static gint fullscreen_controls_delete(GtkWidget *widget, GdkEventAny *event, gpointer data)
{
	/* this is not allowed to be destroyed via WM */
	return TRUE;
}

static void fullscreen_controls_destroy(GtkWidget *widget, gpointer data)
{
	fullscreen_ui = NULL;
}

void fullscreen_start(void)
{
	if (fullscreen_enabled) return;

	fullscreen_enabled = TRUE;
	fullscreen_key_focus = slik_focus_enable;
	slik_focus_enable = FALSE;

	gqoob_xine_fullscreen_set(fullscreen_enabled);

	fullscreen_ui = ui_spawn_child(main_window, "fullscreen_controls", "GQoob Fullscreen Controls", "skindata_fullscreen");

	if (fullscreen_ui)
		{
		gint x, y;

		gtk_signal_connect(GTK_OBJECT(fullscreen_ui->window), "delete_event",
				   GTK_SIGNAL_FUNC(fullscreen_controls_delete), fullscreen_ui);
		gtk_signal_connect(GTK_OBJECT(fullscreen_ui->window), "destroy",
				   GTK_SIGNAL_FUNC(fullscreen_controls_destroy), fullscreen_ui);

		if (!ui_state_get(filename_from_path(fullscreen_ui->skin_path),
			fullscreen_ui->skin_mode_key, &x, &y, NULL, NULL))
			{
			/* FIXME: determine position relative to fullscreen window instead of the desktop size */
			x = gdk_screen_width() - fullscreen_ui->skin->width - FULLSCREEN_EDGE;
			y = gdk_screen_height() - fullscreen_ui->skin->height - FULLSCREEN_EDGE;
			}
		gtk_window_move(GTK_WINDOW(fullscreen_ui->window), x, y);
		gtk_widget_show(fullscreen_ui->window);
		}
	else
		{
		printf("no fullscreen controls available for this skin\n");
		}
}

void fullscreen_stop(void)
{
	if (!fullscreen_enabled) return;

	fullscreen_enabled = FALSE;
	slik_focus_enable = fullscreen_key_focus;

	gqoob_xine_fullscreen_set(fullscreen_enabled);

	ui_close(fullscreen_ui);
	fullscreen_ui = NULL;
}

gint fullscreen_running(void)
{
	return fullscreen_enabled;
}

static gint btn_fullscreen_pressed_cb(gpointer data)
{
	if (!fullscreen_enabled)
		{
		fullscreen_start();
		}
	else
		{
		fullscreen_stop();
		}
	return FALSE;
}

void btn_fullscreen_pressed(void)
{
	g_idle_add(btn_fullscreen_pressed_cb, NULL);
}

static gint btn_fullscreen_controls_toggle_pressed_cb(gpointer data)
{
	if (!fullscreen_ui) return FALSE;

	if (GTK_WIDGET_VISIBLE(fullscreen_ui->window))
		{
		gtk_widget_hide(fullscreen_ui->window);
		}
	else
		{
		gint x, y;

		if (ui_state_get(filename_from_path(fullscreen_ui->skin_path),
				 fullscreen_ui->skin_mode_key, &x, &y, NULL, NULL))
			{
			gtk_window_move(GTK_WINDOW(fullscreen_ui->window), x, y);
			}
		gtk_widget_show(fullscreen_ui->window);
		}

	return FALSE;
}

void btn_fullscreen_controls_toggle_pressed(void)
{
	g_idle_add(btn_fullscreen_controls_toggle_pressed_cb, NULL);
}

UIData *fullscreen_controls_ui(void)
{
	return fullscreen_ui;
}

